Cell

Struct Cell 

pub struct Cell {
    pub ch: char,
    pub fg: Color,
    pub bg: Color,
    pub bold: bool,
    pub italic: bool,
    pub underline: bool,
    pub dim: bool,
    pub wide_continuation: bool,
}
A single cell in the terminal buffer.

Fields

ch: charfg: Colorbg: Colorbold: boolitalic: boolunderline: booldim: boolwide_continuation: bool

True if this cell is the second half of a wide character (e.g., emoji, CJK). The renderer should skip these cells since the wide char already occupies the space.

Implementations

Source

impl Cell

pub fn new(ch: char, fg: Color, bg: Color) -> Self

Create a new cell with just character and colors.

pub fn styled( ch: char, fg: Color, bg: Color, bold: bool, italic: bool, underline: bool, dim: bool, ) -> Self

Create a styled cell.

pub fn wide_continuation(fg: Color, bg: Color) -> Self

Create a wide character continuation cell (second half of emoji/CJK). The renderer should skip these cells.

pub fn wide_continuation_styled( fg: Color, bg: Color, bold: bool, italic: bool, underline: bool, dim: bool, ) -> Self

Create a styled wide character continuation cell.