Module command_system

Module command_system 

Unified command system for Command Palette and Menu Bar.

Commands are defined once and can be used in both the Command Palette (fuzzy search) and Menu Bar (dropdown menus).

Structs

Command
A command that can be executed from the Command Palette or Menu Bar.
CommandBuilder
Builder for creating commands.
Commands
A collection of commands.
MenuDefinition
Menu bar definition.

Enums

MenuItem
A menu item for the menu bar.