FormField

Struct FormField 

pub struct FormField {
    pub name: String,
    pub value: String,
    pub validators: Vec<Validator>,
    pub error: Option<String>,
    pub custom_error_message: Option<String>,
    pub touched: bool,
}
A single field in a form.

Fields

name: String

The field name (identifier).

value: String

Current value.

validators: Vec<Validator>

Validators to apply.

error: Option<String>

Current error message (if validation failed).

custom_error_message: Option<String>

Custom error message to use instead of validator messages.

touched: bool

Whether this field has been “touched” (user interacted with it).

Implementations

Source

impl FormField

pub fn new(name: impl Into<String>) -> Self

Create a new form field.

pub fn value(self, value: impl Into<String>) -> Self

Set the initial value.

pub fn validate(self, validator: Validator) -> Self

Add a validator.

pub fn error_message(self, message: impl Into<String>) -> Self

Set a custom error message to use for any validation failure.

pub fn run_validation(&mut self) -> Option<String>

Run validation and return the error if any.

pub fn is_valid(&self) -> bool

Check if the field is valid (no error).