pub struct Buffer {
pub width: u16,
pub height: u16,
/* private fields */
}Expand description
A 2D buffer of cells representing the terminal screen.
Fields
width: u16height: u16Implementations
Sourceimpl Buffer
impl Buffer
Sourcepub fn set(&mut self, x: u16, y: u16, ch: char, fg: Color, bg: Color)
pub fn set(&mut self, x: u16, y: u16, ch: char, fg: Color, bg: Color)
Set a character at a position with colors.
Sourcepub fn write_str(&mut self, x: u16, y: u16, s: &str, fg: Color, bg: Color)
pub fn write_str(&mut self, x: u16, y: u16, s: &str, fg: Color, bg: Color)
Write a string at a position, clipping at buffer boundaries.
Handles grapheme clusters and wide characters (CJK, emoji) properly:
- Iterates by grapheme clusters (user-perceived characters)
- Wide characters (display width 2) advance the column by 2
- Wide char continuations are marked so the renderer can skip them
Sourcepub fn write_str_styled(
&mut self,
x: u16,
y: u16,
s: &str,
fg: Color,
bg: Color,
bold: bool,
italic: bool,
underline: bool,
dim: bool,
)
pub fn write_str_styled( &mut self, x: u16, y: u16, s: &str, fg: Color, bg: Color, bold: bool, italic: bool, underline: bool, dim: bool, )
Write a styled string at a position, clipping at buffer boundaries.
Handles grapheme clusters and wide characters (CJK, emoji) properly:
- Iterates by grapheme clusters (user-perceived characters)
- Wide characters (display width 2) advance the column by 2
- Wide char continuations are marked so the renderer can skip them