pub struct Cell {
pub ch: char,
pub fg: Color,
pub bg: Color,
pub bold: bool,
pub italic: bool,
pub underline: bool,
pub dim: bool,
pub wide_continuation: bool,
}Expand description
A single cell in the terminal buffer.
Fields
ch: charfg: Colorbg: Colorbold: boolitalic: boolunderline: booldim: boolwide_continuation: boolTrue if this cell is the second half of a wide character (e.g., emoji, CJK). The renderer should skip these cells since the wide char already occupies the space.
Implementations
Sourceimpl Cell
impl Cell
Sourcepub fn new(ch: char, fg: Color, bg: Color) -> Self
pub fn new(ch: char, fg: Color, bg: Color) -> Self
Create a new cell with just character and colors.
Sourcepub fn styled(
ch: char,
fg: Color,
bg: Color,
bold: bool,
italic: bool,
underline: bool,
dim: bool,
) -> Self
pub fn styled( ch: char, fg: Color, bg: Color, bold: bool, italic: bool, underline: bool, dim: bool, ) -> Self
Create a styled cell.
Sourcepub fn wide_continuation(fg: Color, bg: Color) -> Self
pub fn wide_continuation(fg: Color, bg: Color) -> Self
Create a wide character continuation cell (second half of emoji/CJK). The renderer should skip these cells.