Unified command system for Command Palette and Menu Bar.
Commands are defined once and can be used in both the Command Palette (fuzzy search) and Menu Bar (dropdown menus).
Structs
- Command
- A command that can be executed from the Command Palette or Menu Bar.
- Command
Builder - Builder for creating commands.
- Commands
- A collection of commands.
- Menu
Definition - Menu bar definition.
Enums
- Menu
Item - A menu item for the menu bar.