pub struct Terminal { /* private fields */ }Expand description
Terminal wrapper that handles setup, rendering, and cleanup.
Implementations
Sourceimpl Terminal
impl Terminal
Sourcepub fn new() -> Result<Self>
pub fn new() -> Result<Self>
Create a new terminal instance. Enters raw mode and the alternate screen.
Sourcepub fn draw(
&mut self,
view: &View,
focus_index: usize,
focus_visible: bool,
scroll_offsets: Vec<(u16, u16)>,
cursor_offsets: Vec<usize>,
modal_visible: bool,
) -> Result<Vec<(u16, u16)>>
pub fn draw( &mut self, view: &View, focus_index: usize, focus_visible: bool, scroll_offsets: Vec<(u16, u16)>, cursor_offsets: Vec<usize>, modal_visible: bool, ) -> Result<Vec<(u16, u16)>>
Draw a view to the terminal. Returns clamped scroll offsets to apply back to FocusManager.
Sourcepub fn poll_event(&self) -> Result<Option<Event>>
pub fn poll_event(&self) -> Result<Option<Event>>
Poll for an input event with a small timeout.