Trait Component
Source pub trait Component {
// Required method
fn render(&self, cx: Scope) -> View;
}
A component that can render itself to a View.
Render this component to a View tree.
SourceBlanket implementation for closures that take Scope and return View.
This enables: telex::run(|cx| view! { … })